# raymond

![](https://github.com/RaymondKirk/raymond/workflows/build/badge.svg)

Utility package for raymond specific functions.

## Documentation

Please refer to the [documentation](https://raymondkirk.github.io/raymond/) for installation instructions and API usage.

## Citing raymond


If you use raymond in your research please use the following BibTeX entry and any BibTeX entries for used functions.

```BibTeX
@misc{rk2020raymond,
  author =       {Raymond Kirk},
  title =        {raymond},
  howpublished = {\url{https://github.com/RaymondKirk/raymond}},
  year =         {2020}
}
```
